@@ -25,6 +25,10 @@ when validation of the number fails.
 """
 
 
+__all__ = ['ValidationError', 'InvalidFormat', 'InvalidChecksum',
+           'InvalidLength', 'InvalidComponent']
+
+
 class ValidationError(Exception):
     """Top-level error for validating numbers.
 
@@ -36,7 +40,7 @@ class ValidationError(Exception):
         return ''.join(self.args[:1]) or getattr(self, 'message', '')
 
 
-class InvalidFormat(ValidationError):
+class InvalidFormat(ValidationError):  # noqa N818
     """Something is wrong with the format of the number.
 
     This generally means characters or delimiters that are not allowed are
@@ -45,19 +49,19 @@ class InvalidFormat(ValidationError):
     message = 'The number has an invalid format.'
 
 
-class InvalidChecksum(ValidationError):
+class InvalidChecksum(ValidationError):  # noqa N818
     """The number's internal checksum or check digit does not match."""
 
     message = "The number's checksum or check digit is invalid."
 
 
-class InvalidLength(InvalidFormat):
+class InvalidLength(InvalidFormat):  # noqa N818
     """The length of the number is wrong."""
 
     message = 'The number has an invalid length.'
 
 
-class InvalidComponent(ValidationError):
+class InvalidComponent(ValidationError):  # noqa N818
     """One of the parts of the number has an invalid reference.
 
     Some part of the number refers to some external entity like a country
